From 501d308495ee6e17006eb6618d39e8b19166b19c Mon Sep 17 00:00:00 2001
From: Jon Lund Steffensen <jonlst@gmail.com>
Date: Sun, 28 Dec 2014 14:14:25 -0500
Subject: location: Make translated string about recheck shared between all
 providers

---
 src/location-corelocation.m | 6 +++---
 src/location-geoclue.c      | 6 +++---
 src/location-geoclue2.c     | 6 +++---
 3 files changed, 9 insertions(+), 9 deletions(-)

(limited to 'src')

diff --git a/src/location-corelocation.m b/src/location-corelocation.m
index cc873bb..edf3e45 100644
--- a/src/location-corelocation.m
+++ b/src/location-corelocation.m
@@ -127,9 +127,9 @@ location_corelocation_print_help(FILE *f)
 	fputs(_("Use the location as discovered by the Corelocation provider.\n"), f);
 	fputs("\n", f);
 
-	fputs(_("NOTE: currently redshift doesn't recheck CoreLocation once started,\n"
-		"which means it has to be restarted to take notice after travel.\n"),
-	      f);
+	fprintf(f, _("NOTE: currently Redshift doesn't recheck %s once started,\n"
+		     "which means it has to be restarted to take notice after travel.\n"),
+		"CoreLocation");
 	fputs("\n", f);
 }
 
diff --git a/src/location-geoclue.c b/src/location-geoclue.c
index 07865c5..378b933 100644
--- a/src/location-geoclue.c
+++ b/src/location-geoclue.c
@@ -137,9 +137,9 @@ location_geoclue_print_help(FILE *f)
 	fputs(_("  name=N\tName of Geoclue provider (or `default')\n"
 		"  path=N\tPath of Geoclue provider (or `default')\n"), f);
 	fputs("\n", f);
-	fputs(_("NOTE: currently redshift doesn't recheck geoclue once started,\n"
-		"which means it has to be restarted to take notice after travel.\n"),
-	      f);
+	fprintf(f, _("NOTE: currently Redshift doesn't recheck %s once started,\n"
+		     "which means it has to be restarted to take notice after travel.\n"),
+		"GeoClue");
 	fputs("\n", f);
 }
 
diff --git a/src/location-geoclue2.c b/src/location-geoclue2.c
index 4c4150e..9b9b725 100644
--- a/src/location-geoclue2.c
+++ b/src/location-geoclue2.c
@@ -69,9 +69,9 @@ location_geoclue2_print_help(FILE *f)
 	fputs(_("Use the location as discovered by a GeoClue2 provider.\n"), f);
 	fputs("\n", f);
 
-	fputs(_("NOTE: currently redshift doesn't recheck GeoClue2 once started,\n"
-		"which means it has to be restarted to take notice after travel.\n"),
-	      f);
+	fprintf(f, _("NOTE: currently Redshift doesn't recheck %s once started,\n"
+		     "which means it has to be restarted to take notice after travel.\n"),
+		"GeoClue2");
 	fputs("\n", f);
 }
 
-- 
cgit v1.2.3-70-g09d2


From 0b94ec26fed58360181df1fcdd7022506508e1c9 Mon Sep 17 00:00:00 2001
From: Jon Lund Steffensen <jonlst@gmail.com>
Date: Sun, 28 Dec 2014 14:34:21 -0500
Subject: redshift: Add translation of Daytime/Night in new gamma string

---
 src/redshift.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

(limited to 'src')

diff --git a/src/redshift.c b/src/redshift.c
index c22826b..9e48aa0 100644
--- a/src/redshift.c
+++ b/src/redshift.c
@@ -1280,10 +1280,12 @@ main(int argc, char *argv[])
 	}
 
 	if (verbose) {
+		/* TRANSLATORS: The string in parenthesis is either
+		   Daytime or Night (translated). */
 		printf(_("Gamma (%s): %.3f, %.3f, %.3f\n"),
-		       "Day", day.gamma[0], day.gamma[1], day.gamma[2]);
+		       _("Daytime"), day.gamma[0], day.gamma[1], day.gamma[2]);
 		printf(_("Gamma (%s): %.3f, %.3f, %.3f\n"),
-		       "Night", night.gamma[0], night.gamma[1], night.gamma[2]);
+		       _("Night"), night.gamma[0], night.gamma[1], night.gamma[2]);
 	}
 
 	/* Initialize gamma adjustment method. If method is NULL
-- 
cgit v1.2.3-70-g09d2


From f154aaa7c1877703308a71ca9d1ba34823a69bf0 Mon Sep 17 00:00:00 2001
From: Jon Lund Steffensen <jonlst@gmail.com>
Date: Sun, 28 Dec 2014 14:34:43 -0500
Subject: redshift: Add translation comment on period name None

---
 src/redshift.c | 1 +
 1 file changed, 1 insertion(+)

(limited to 'src')

diff --git a/src/redshift.c b/src/redshift.c
index 9e48aa0..60cd9f5 100644
--- a/src/redshift.c
+++ b/src/redshift.c
@@ -306,6 +306,7 @@ typedef enum {
 
 /* Names of periods of day */
 static const char *period_names[] = {
+	/* TRANSLATORS: Name printed when period of day is unknown */
 	N_("None"),
 	N_("Daytime"),
 	N_("Night"),
-- 
cgit v1.2.3-70-g09d2


From d281e0c1ed2e6f787c17f4b8b5eaad7a2c29f1fb Mon Sep 17 00:00:00 2001
From: Jon Lund Steffensen <jonlst@gmail.com>
Date: Sun, 28 Dec 2014 14:33:11 -0500
Subject: redshift: Add translation comment to N,S,W,E strings

---
 src/redshift.c | 19 ++++++++++++++++---
 1 file changed, 16 insertions(+), 3 deletions(-)

(limited to 'src')

diff --git a/src/redshift.c b/src/redshift.c
index 5f7d22b..c22826b 100644
--- a/src/redshift.c
+++ b/src/redshift.c
@@ -1178,12 +1178,25 @@ main(int argc, char *argv[])
 		provider->free(&location_state);
 	
 		if (verbose) {
-		        /* TRANSLATORS: Append degree symbols after %f if possible. */
+			/* TRANSLATORS: Abbreviation for `north' */
+			const char *north = _("N");
+			/* TRANSLATORS: Abbreviation for `south' */
+			const char *south = _("S");
+			/* TRANSLATORS: Abbreviation for `east' */
+			const char *east = _("E");
+			/* TRANSLATORS: Abbreviation for `west' */
+			const char *west = _("W");
+
+		        /* TRANSLATORS: Append degree symbols after %f if possible.
+			   The string following each number is an abreviation for
+			   north, source, east or west (N, S, E, W). */
 		        printf(_("Location: %.2f %s, %.2f %s\n"),
-			       fabs(lat), lat >= 0.f ? _("N") : _("S"),
-			       fabs(lon), lon >= 0.f ? _("E") : _("W"));
+			       fabs(lat), lat >= 0.f ? north : south,
+			       fabs(lon), lon >= 0.f ? east : west);
+
 			printf(_("Temperatures: %dK at day, %dK at night\n"),
 			       day.temperature, night.temperature);
+
 		        /* TRANSLATORS: Append degree symbols if possible. */
 			printf(_("Solar elevations: day above %.1f, night below %.1f\n"),
 			       transition_high, transition_low);
-- 
cgit v1.2.3-70-g09d2